package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OutputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.ocsp.CertID;
import cn.com.infosec.asn1.ocsp.OCSPRequest;
import cn.com.infosec.asn1.ocsp.Request;
import cn.com.infosec.asn1.ocsp.Signature;
import cn.com.infosec.asn1.ocsp.TBSRequest;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.SecureRandom;
import java.security.cert.CertificateEncodingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.security.auth.x500.X500Principal;

public class OCSPReqGenerator {
   private List list;
   private GeneralName requestorName;
   private X509Extensions requestExtensions;

   public OCSPReqGenerator() {
      OCSPReqGenerator var10000 = this;
      OCSPReqGenerator var10001 = this;
      OCSPReqGenerator var10002 = this;
      super();
      ArrayList var1;
      var1 = new ArrayList.<init>();
      var10002.list = var1;
      var10001.requestorName = null;
      var10000.requestExtensions = null;
   }

   private DERObject makeObj(byte[] encoding) {
      return encoding == null ? null : (new ASN1InputStream(encoding)).readObject();
   }

   private OCSPReq generateRequest(DERObjectIdentifier signingAlgorithm, PrivateKey key, X509Certificate[] chain, String provider, SecureRandom random) {
      Iterator var6 = this.list.iterator();
      ASN1EncodableVector var7;
      var7 = new ASN1EncodableVector.<init>();

      while(var6.hasNext()) {
         try {
            var7.add(((RequestObject)var6.next()).toRequest());
         } catch (Exception var10) {
            throw new OCSPException("exception creating Request", var10);
         }
      }

      NoSuchAlgorithmException var42;
      label116: {
         InvalidKeyException var10000;
         label115: {
            IOException var52;
            label131: {
               CertificateEncodingException var51;
               label129: {
                  TBSRequest var39;
                  TBSRequest var10001 = var39 = new TBSRequest;
                  GeneralName var8 = this.requestorName;
                  DERSequence var9;
                  var9 = new DERSequence.<init>(var7);
                  X509Extensions var40 = this.requestExtensions;
                  var10001.<init>(var8, var9, var40);
                  Signature var41 = null;
                  if (signingAlgorithm != null) {
                     if (this.requestorName == null) {
                        throw new OCSPException("requestorName must be specified if request is signed.");
                     }

                     SecureRandom var43;
                     boolean var44;
                     java.security.Signature var45;
                     try {
                        var43 = random;
                        var45 = java.security.Signature.getInstance(signingAlgorithm.getId(), provider);
                     } catch (NoSuchAlgorithmException var15) {
                        var42 = var15;
                        var44 = false;
                        break label116;
                     } catch (InvalidKeyException var16) {
                        var10000 = var16;
                        var44 = false;
                        break label115;
                     }

                     java.security.Signature provider1 = var45;
                     if (var43 != null) {
                        try {
                           provider1.initSign(key, random);
                        } catch (NoSuchAlgorithmException var13) {
                           var42 = var13;
                           var44 = false;
                           break label116;
                        } catch (InvalidKeyException var14) {
                           var10000 = var14;
                           var44 = false;
                           break label115;
                        }
                     } else {
                        try {
                           provider1.initSign(key);
                        } catch (NoSuchAlgorithmException var11) {
                           var42 = var11;
                           var44 = false;
                           break label116;
                        } catch (InvalidKeyException var12) {
                           var10000 = var12;
                           var44 = false;
                           break label115;
                        }
                     }

                     DERBitString key2;
                     X509Certificate[] var48;
                     label90: {
                        Exception var47;
                        label126: {
                           ByteArrayOutputStream var10002;
                           try {
                              var48 = chain;
                              var45 = provider1;
                              var10002 = new ByteArrayOutputStream;
                           } catch (Exception var20) {
                              var47 = var20;
                              var44 = false;
                              break label126;
                           }

                           ByteArrayOutputStream key1;
                           ByteArrayOutputStream var10003 = key1 = var10002;

                           ASN1OutputStream var49;
                           try {
                              var10003.<init>();
                              var49 = new ASN1OutputStream;
                           } catch (Exception var19) {
                              var47 = var19;
                              var44 = false;
                              break label126;
                           }

                           ASN1OutputStream var10004 = var49;

                           DERBitString var50;
                           try {
                              var10004.<init>(key1);
                              var49.writeObject(var39);
                              var45.update(var10002.toByteArray());
                              var50 = new DERBitString;
                           } catch (Exception var18) {
                              var47 = var18;
                              var44 = false;
                              break label126;
                           }

                           key2 = var50;

                           try {
                              var50.<init>(provider1.sign());
                              break label90;
                           } catch (Exception var17) {
                              var47 = var17;
                              var44 = false;
                           }
                        }

                        Exception var27 = var47;
                        throw new OCSPException("exception processing TBSRequest: " + var27, var27);
                     }

                     AlgorithmIdentifier provider2;
                     AlgorithmIdentifier var53 = provider2 = new AlgorithmIdentifier;
                     DERNull signingAlgorithm1;
                     signingAlgorithm1 = new DERNull.<init>();
                     var53.<init>(signingAlgorithm, signingAlgorithm1);
                     if (var48 != null && chain.length > 0) {
                        ASN1EncodableVector signingAlgorithm2;
                        signingAlgorithm2 = new ASN1EncodableVector.<init>();
                        int random1 = 0;

                        while(true) {
                           int var54;
                           int var55;
                           try {
                              var54 = random1;
                              var55 = chain.length;
                           } catch (IOException var21) {
                              var52 = var21;
                              var44 = false;
                              break label131;
                           } catch (CertificateEncodingException var22) {
                              var51 = var22;
                              var44 = false;
                              break label129;
                           }

                           if (var54 == var55) {
                              Signature var56 = var41 = new Signature;
                              DERSequence var32;
                              var32 = new DERSequence.<init>(signingAlgorithm2);
                              var56.<init>(provider2, key2, var32);
                              break;
                           }

                           try {
                              signingAlgorithm2.add(new X509CertificateStructure((ASN1Sequence)this.makeObj(chain[random1].getEncoded())));
                           } catch (IOException var23) {
                              var52 = var23;
                              var44 = false;
                              break label131;
                           } catch (CertificateEncodingException var24) {
                              var51 = var24;
                              var44 = false;
                              break label129;
                           }

                           ++random1;
                        }
                     } else {
                        var41 = new Signature.<init>(provider2, key2);
                     }
                  }

                  OCSPRequest var33;
                  var33 = new OCSPRequest.<init>(var39, var41);
                  return new OCSPReq(var33);
               }

               CertificateEncodingException var29 = var51;
               throw new OCSPException("error encoding certs", var29);
            }

            IOException var31 = var52;
            throw new OCSPException("error processing certs", var31);
         }

         InvalidKeyException var25 = var10000;
         throw new OCSPException("exception creating signature: " + var25, var25);
      }

      NoSuchAlgorithmException var26 = var42;
      throw new OCSPException("exception creating signature: " + var26, var26);
   }

   public void addRequest(CertificateID certId) {
      this.list.add(new RequestObject(certId, (X509Extensions)null));
   }

   public void addRequest(CertificateID certId, X509Extensions singleRequestExtensions) {
      this.list.add(new RequestObject(certId, singleRequestExtensions));
   }

   public void setRequestorName(X500Principal param1) {
      // $FF: Couldn't be decompiled
   }

   public void setRequestorName(GeneralName requestorName) {
      this.requestorName = requestorName;
   }

   public void setRequestExtensions(X509Extensions requestExtensions) {
      this.requestExtensions = requestExtensions;
   }

   public OCSPReq generate() {
      try {
         return this.generateRequest((DERObjectIdentifier)null, (PrivateKey)null, (X509Certificate[])null, (String)null, (SecureRandom)null);
      } catch (NoSuchProviderException var1) {
         throw new OCSPException("no provider! - " + var1, var1);
      }
   }

   public OCSPReq generate(String signingAlgorithm, PrivateKey key, X509Certificate[] chain, String provider) {
      return this.generate(signingAlgorithm, key, chain, provider, (SecureRandom)null);
   }

   public OCSPReq generate(String signingAlgorithm, PrivateKey key, X509Certificate[] chain, String provider, SecureRandom random) {
      if (signingAlgorithm != null) {
         try {
            return this.generateRequest(OCSPUtil.getAlgorithmOID(signingAlgorithm), key, chain, provider, random);
         } catch (IllegalArgumentException var6) {
            throw new IllegalArgumentException("unknown signing algorithm specified: " + signingAlgorithm);
         }
      } else {
         throw new IllegalArgumentException("no signing algorithm specified");
      }
   }

   public Iterator getSignatureAlgNames() {
      return OCSPUtil.getAlgNames();
   }

   private class RequestObject {
      CertificateID certId;
      X509Extensions extensions;

      public RequestObject(CertificateID certId, X509Extensions extensions) {
         this.certId = certId;
         this.extensions = extensions;
      }

      public Request toRequest() {
         RequestObject var10002 = this;
         CertID var1 = this.certId.toASN1Object();
         return new Request(var1, var10002.extensions);
      }
   }
}
